﻿using System;
using System.Threading.Tasks;
using Microsoft.AspNetCore.Builder;
using Microsoft.AspNetCore.Hosting;
using Microsoft.AspNetCore.Http;
using Microsoft.Extensions.DependencyInjection;
using Microsoft.Extensions.Hosting;
using Prometheus;

namespace PrometheusExporterEdenic
{
    public class Program
    {
        public static void Main(string[] args)
        {
            CreateHostBuilder(args).Build().Run();
        }

        public static IHostBuilder CreateHostBuilder(string[] args) =>
            Host.CreateDefaultBuilder(args)
                .ConfigureWebHostDefaults(webBuilder =>
                {
                    webBuilder.UseStartup<Startup>();
                });
    }

    public class Startup
    {
        public void ConfigureServices(IServiceCollection services)
        {
        }

        public void Configure(IApplicationBuilder app, IWebHostEnvironment env)
        {
            if (env.IsDevelopment())
            {
                app.UseDeveloperExceptionPage();
            }
            
            string EDENIC_ORGID = Environment.GetEnvironmentVariable("EDENIC_ORGID") ?? "9ffb9b70-461c-11ef-92e1-85f1b2168e5a";
            string EDENIC_API = Environment.GetEnvironmentVariable("EDENIC_API") ?? "ed_tjf14py97vz1cf4ugxljiiqwckxkhzim0coqogqmk1x99rfjlgi1q2vxesav4z55";
            
            // Enable prometheus metrics
            app.UseMetricServer();
            app.UseHttpMetrics();

            app.UseRouting();

            app.UseEndpoints(endpoints =>
            {
                endpoints.MapGet("/", async context =>
                {
                    await context.Response.WriteAsync("Open /metrics");
                });
            });

            // Define custom metrics
            var ph = Metrics.CreateGauge("edenic_ph", "Edenic ph");
            var temperature = Metrics.CreateGauge("edenic_temperature", "Edenic temperature");
            var ec = Metrics.CreateGauge("edenic_ec", "Edenic EC");
            Task.Run(async () =>
            {
                while (true)
                {
                    ph.Set(1);
                    temperature.Set(1);
                    ec.Set(1);
                    await Task.Delay(1000);
                }
            });
        }
    }
}